@@ -1,14 +1,15 @@
 """Performance testing utility."""
 
-from ._format_perf_counter import format_perf_counter
+from ._format_perf_counter import format_perf_counter, format_seconds
 from ._multi_case_timer import MultiCaseTimer
 from ._util import plot_run, to_dataframe
-from ._wrappers import run_multivariate_test
+from ._wrapper import run_multivariate_test
 
 __all__ = [
     "MultiCaseTimer",
     "run_multivariate_test",
     "format_perf_counter",
+    "format_seconds",
     "plot_run",
     "to_dataframe",
 ]
